@@ -271,8 +271,10 @@ main(int argc,char **argv)
     {"permute",required_argument,0,'a'},
     {"reorder",required_argument,0,'a'},
     {"rdr",required_argument,0,'a'},
-    {"no-coords",no_argument,0,'C'},
-    {"no-crd",no_argument,0,'C'},
+    {"xtr_ass_var",no_argument,0,'c'},
+    {"xcl_ass_var",no_argument,0,'C'},
+    {"no_coords",no_argument,0,'C'},
+    {"no_crd",no_argument,0,'C'},
     {"coords",no_argument,0,'c'},
     {"crd",no_argument,0,'c'},
     {"debug",required_argument,0,'D'},
@@ -520,7 +522,7 @@ main(int argc,char **argv)
   } /* end while loop */
   
   /* Process positional arguments and fill-in filenames */
-  fl_lst_in=nco_fl_lst_mk(argv,argc,optind,&fl_nbr,&fl_out,&FL_LST_IN_FROM_STDIN);
+  fl_lst_in=nco_fl_lst_mk(argv,argc,optind,&fl_nbr,&fl_out,&FL_LST_IN_FROM_STDIN,FORCE_OVERWRITE);
   
   /* Make uniform list of user-specified chunksizes */
   if(cnk_nbr > 0) cnk_dmn=nco_cnk_prs(cnk_nbr,cnk_arg);
