@@ -145,6 +145,7 @@ main(int argc,char **argv)
   char *rgr_grd_dst=NULL; /* [sng] File containing destination grid */
   char *rgr_map=NULL; /* [sng] File containing mapping weights from source to destination grid */
   char *rgr_var=NULL; /* [sng] Variable for special regridding treatment */
+  char *rgr_vrt=NULL; /* [sng] File containing vertical coordinate grid */
   char *smr_fl_sz_sng=NULL; /* [sng] String describing estimated file size */
   char *smr_sng=NULL; /* [sng] File summary string */
   char *smr_xtn_sng=NULL; /* [sng] File extended summary string */
@@ -182,6 +183,7 @@ main(int argc,char **argv)
   int *in_id_arr; /* [id] netCDF file IDs used by OpenMP code */
 
   int JSN_ATT_FMT=0; /* [enm] JSON format for netCDF attributes: 0 (no object, only data), 1 (data only for string, char, int, and floating-point types, otherwise object), 2 (always object) */
+  int JSN_VAR_FMT=2; /* [flg] JSON format for netCDF variables: 0 (no type except for user-defined types), 1 (type for non-default types), 2 (always type) */
   nco_bool JSN_DATA_BRK=True; /* [flg] JSON format for netCDF variables: 0 (no brackets), 1 (bracket inner dimensions of multi-dimensional data) */
 
   int abb_arg_nbr=0;
@@ -226,6 +228,7 @@ main(int argc,char **argv)
   md5_sct *md5=NULL; /* [sct] MD5 configuration */
  
   nco_bool ALPHABETIZE_OUTPUT=True; /* Option a */
+  nco_bool CHK_NAN=False; /* [flg] Check for NaNs */
   nco_bool CPY_GRP_METADATA; /* [flg] Copy group metadata (attributes) */
   nco_bool EXCLUDE_INPUT_LIST=False; /* Option x */
   nco_bool EXTRACT_ALL_COORDINATES=False; /* Option c */
@@ -314,6 +317,9 @@ main(int argc,char **argv)
     {"formula_terms",no_argument,0,0}, /* [flg] Extract formula_terms variables */
     {"no_frm_trm",no_argument,0,0}, /* [flg] Do not extract formula_terms variables */
     {"no_formula_terms",no_argument,0,0}, /* [flg] Do not extract formula_terms variables */
+    {"chk_nan",no_argument,0,0}, /* [flg] Check file for NaNs */
+    {"nan",no_argument,0,0}, /* [flg] Check file for NaNs */
+    {"NaN",no_argument,0,0}, /* [flg] Check file for NaNs */
     {"clean",no_argument,0,0}, /* [flg] Clean memory prior to exit */
     {"mmr_cln",no_argument,0,0}, /* [flg] Clean memory prior to exit */
     {"drt",no_argument,0,0}, /* [flg] Allow dirty memory on exit */
@@ -457,6 +463,9 @@ main(int argc,char **argv)
     {"map_file",required_argument,0,0}, /* [sng] File containing mapping weights from source to destination grid */
     {"rgr_var",required_argument,0,0}, /* I [sng] Variable for special regridding treatment */
     {"rgr_rnr",required_argument,0,0}, /* [flg] Renormalize destination values by valid area */
+    {"rgr_vrt",required_argument,0,0}, /* [sng] File containing vertical coordinate grid */
+    {"vrt_fl",required_argument,0,0}, /* [sng] File containing vertical coordinate grid */
+    {"vrt_crd",required_argument,0,0}, /* [sng] File containing vertical coordinate grid */
     {"rnr_thr",required_argument,0,0}, /* [flg] Renormalize destination values by valid area */
     {"renormalize",required_argument,0,0}, /* [flg] Renormalize destination values by valid area */
     {"trr",required_argument,0,0}, /* [sng] Terraref */
@@ -488,8 +497,10 @@ main(int argc,char **argv)
     {"fl_bnr",required_argument,0,'b'},
     {"coords",no_argument,0,'c'},
     {"crd",no_argument,0,'c'},
-    {"no-coords",no_argument,0,'C'},
-    {"no-crd",no_argument,0,'C'},
+     {"xtr_ass_var",no_argument,0,'c'},
+    {"xcl_ass_var",no_argument,0,'C'},
+    {"no_coords",no_argument,0,'C'},
+    {"no_crd",no_argument,0,'C'},
     {"data",required_argument,0,'H'},
     {"debug",required_argument,0,'D'},
     {"dbg_lvl",required_argument,0,'D'},
@@ -606,6 +617,7 @@ main(int argc,char **argv)
 	PRN_CLN_LGB=True;
 	PRN_CDL=True;
       } /* !dt_fmt */
+      if(!strcmp(opt_crr,"chk_nan") || !strcmp(opt_crr,"nan") || !strcmp(opt_crr,"NaN")) CHK_NAN=True; /* [flg] Check for NaNs */
       if(!strcmp(opt_crr,"cnk_byt") || !strcmp(opt_crr,"chunk_byte")){
         cnk_sz_byt=strtoul(optarg,&sng_cnv_rcd,NCO_SNG_CNV_BASE10);
         if(*sng_cnv_rcd) nco_sng_cnv_err(optarg,"strtoul",sng_cnv_rcd);
@@ -736,6 +748,10 @@ main(int argc,char **argv)
         flg_rgr=True;
 	rgr_map=(char *)strdup(optarg);
       } /* endif rgr_map */
+      if(!strcmp(opt_crr,"vrt_fl") || !strcmp(opt_crr,"vrt_crd") || !strcmp(opt_crr,"rgr_vrt")){
+        flg_rgr=True;
+	rgr_vrt=(char *)strdup(optarg);
+      } /* !vrt_fl */
       if(!strcmp(opt_crr,"rnr_thr") || !strcmp(opt_crr,"rgr_rnr") || !strcmp(opt_crr,"renormalize")){
         wgt_vld_thr=strtod(optarg,&sng_cnv_rcd);
         if(*sng_cnv_rcd) nco_sng_cnv_err(optarg,"strtod",sng_cnv_rcd);
@@ -800,6 +816,7 @@ main(int argc,char **argv)
 	if(JSN_ATT_FMT >= 4) JSN_DATA_BRK=False; /* [flg] Print JSON with bracket data */
 	JSN_ATT_FMT%=4; /* 20161221: Valid values are 0,1,2 */
 	if(JSN_ATT_FMT == 3) JSN_ATT_FMT=2;
+	JSN_VAR_FMT=JSN_ATT_FMT;
       } /* !jsn_att_fmt */
       if(!strcmp(opt_crr,"jsn") || !strcmp(opt_crr,"json") || !strcmp(opt_crr,"w10") || !strcmp(opt_crr,"w10n")) PRN_JSN=True; /* [flg] Print JSON */
       if(!strcmp(opt_crr,"wrt_tmp_fl") || !strcmp(opt_crr,"write_tmp_fl")) WRT_TMP_FL=True;
@@ -1011,7 +1028,7 @@ main(int argc,char **argv)
   (void)trv_tbl_init(&trv_tbl);
  
   /* Process positional arguments and fill-in filenames */
-  fl_lst_in=nco_fl_lst_mk(argv,argc,optind,&fl_nbr,&fl_out,&FL_LST_IN_FROM_STDIN);
+  fl_lst_in=nco_fl_lst_mk(argv,argc,optind,&fl_nbr,&fl_out,&FL_LST_IN_FROM_STDIN,FORCE_OVERWRITE);
   
   /* Initialize thread information */
   if(flg_rgr) thr_nbr=nco_openmp_ini(thr_nbr); else thr_nbr=nco_openmp_ini((int)1);
@@ -1134,7 +1151,7 @@ main(int argc,char **argv)
       /* Initialize regridding structure */
       rgr_in=(char *)strdup(fl_in);
       rgr_out=(char *)strdup(fl_out);
-      rgr_nfo=nco_rgr_ini(cmd_ln,in_id,rgr_arg,rgr_nbr,rgr_in,rgr_out,rgr_grd_src,rgr_grd_dst,rgr_map,rgr_var,wgt_vld_thr,xtn_lst_in,xtn_nbr);
+      rgr_nfo=nco_rgr_ini(cmd_ln,in_id,rgr_arg,rgr_nbr,rgr_in,rgr_out,rgr_grd_src,rgr_grd_dst,rgr_map,rgr_var,rgr_vrt,wgt_vld_thr,xtn_lst_in,xtn_nbr);
       rgr_nfo->fl_out_fmt=fl_out_fmt;
       rgr_nfo->dfl_lvl=dfl_lvl;
       rgr_nfo->fl_out_tmp=nco_fl_out_open(rgr_nfo->fl_out,&FORCE_APPEND,FORCE_OVERWRITE,fl_out_fmt,&bfr_sz_hnt,RAM_CREATE,RAM_OPEN,WRT_TMP_FL,&out_id);
@@ -1297,15 +1314,17 @@ main(int argc,char **argv)
     } /* endif */
 
     if(prn_flg.jsn){
-      /* In JSON, notation 0. or 20. is invalid---correct is 0.0, 20.0 */
+      /* In JSON numeric notation, a terminal decimal place, like 0. and 20., is invalid---correct is 0.0, 20.0 */
       prn_flg.nbr_zro=1;
       /* JSON numerical arrays have no notion of missing values */
       prn_flg.PRN_MSS_VAL_BLANK=False;
       prn_flg.jsn_att_fmt=JSN_ATT_FMT;  
       prn_flg.jsn_data_brk=JSN_DATA_BRK;  
+      prn_flg.jsn_var_fmt=JSN_VAR_FMT;  
     }else { /* endif JSON */
       prn_flg.jsn_att_fmt=0;
       prn_flg.jsn_data_brk=False;
+      prn_flg.jsn_var_fmt=2;
     } /* !JSON */
       
     if(prn_flg.xml) prn_flg.PRN_MSS_VAL_BLANK=False;
@@ -1356,6 +1375,12 @@ main(int argc,char **argv)
       
     }else{ 
 
+      if(CHK_NAN){
+	/* Check floating-point fields for NaNs */
+        nco_chk_nan(in_id,trv_tbl);
+        goto close_and_free;
+      } /* !CHK_NAN */
+
       /* New file dump format(s) developed 201307 for CDL, JSN, SRM, TRD, XML */
       if(PRN_SRM){
 	/* Stream printing is pre-alpha. Great project for volunteers! */
