@@ -345,20 +345,20 @@ extern "C" {
 # define NCO_VERSION_MAJOR 4
 #endif /* !NCO_VERSION_MAJOR */
 #ifndef NCO_VERSION_MINOR
-# define NCO_VERSION_MINOR 7
+# define NCO_VERSION_MINOR 8
 #endif /* !NCO_VERSION_MINOR */
 #ifndef NCO_VERSION_PATCH
-# define NCO_VERSION_PATCH 9
+# define NCO_VERSION_PATCH 1
 #endif /* !NCO_VERSION_PATCH */
 #ifndef NCO_VERSION_NOTE
-# define NCO_VERSION_NOTE "" /* Blank for final versions, non-blank (e.g., "-beta37") for pre-release versions */
+# define NCO_VERSION_NOTE "-beta01" /* Blank for final versions, non-blank (e.g., "-beta37") for pre-release versions */
 #endif /* !NCO_VERSION_NOTE */
 #ifndef NCO_LIB_VERSION
   /* Define NC_LIB_VERSION as three-digit number for arithmetic comparisons by CPP */
 # define NCO_LIB_VERSION ( NCO_VERSION_MAJOR * 100 + NCO_VERSION_MINOR * 10 + NCO_VERSION_PATCH )
 #endif /* !NCO_LIB_VERSION */
 #ifndef NCO_VERSION
-# define NCO_VERSION "4.7.9"
+# define NCO_VERSION "4.8.1"
 #endif /* !NCO_VERSION */
 
 /* Compatibility tokens new to netCDF4 netcdf.h: */
@@ -1000,7 +1000,8 @@ extern "C" {
     int fl_out_fmt; /* [enm] Output file format */
     int fll_pth; /* [nbr] Print full paths */
     int jsn_att_fmt; /* [enm] JSON format for netCDF attributes: 0 (no object, only data), 1 (data only for string, char, int, and floating-point types, otherwise object), 2 (always object) */
-    int jsn_data_brk; /* [flg] JSON format for netCDF variables: 0 (no bracketing of var data ), 1 ( bracketing of var data )*/
+    int jsn_data_brk; /* [flg] JSON format for netCDF variables: 0 (no bracketing of var data ), 1 ( bracketing of var data ) */
+    int jsn_var_fmt; /* [flg] JSON format for netCDF variables: 0 (no type except for user-defined types), 1 (type for non-default types), 2 (always type) */
     int nbr_zro; /* [nbr] Trailing zeros allowed after decimal point */
     int ndn; /* [nbr] Indentation */
     int spc_per_lvl; /* [nbr] Indentation spaces per group level */
@@ -1064,6 +1065,21 @@ extern "C" {
     nco_grd_lon_bb, /* Longitude grid determined by bounding box (lon_wst/lon_est) and gridcell number (lon_nbr) */
   } nco_grd_lon_typ_enm;
 
+  typedef enum nco_xtr_typ_enm 
+    { /* [enm] Extrapolation type enum */
+     nco_xtr_fll_lnr=0, // Perform linear extrapolation using two nearest valid neighbors
+     nco_xtr_fll_ngh, // Set extrapolated value to value of nearest valid neighbor
+     nco_xtr_fll_nil, // Set extrapolated value to 0.0
+     nco_xtr_fll_tpt, // Temperature extrapolation assuming moist adiabatic lapse rate dT/dp=constant=(6.5 K)/(10000 Pa)
+     nco_xtr_fll_gph, // Geopotential height extrapolation assuming hydrostatic equation dZ/dp=-RT/pg
+     nco_xtr_fll_msv, // Set extrapolated value to missing value
+     nco_xtr_prt_frc, // Use average value of overlap region
+     nco_xtr_prt_lnr, // Perform linear extrapolation using two nearest valid neighbors
+     nco_xtr_prt_ngh, // Set extrapolated value to value of nearest valid neighbor
+     nco_xtr_prt_nil, // Set extrapolated value to 0.0
+     nco_xtr_prt_wgt // Set extrapolated value to average value of overlap region weighted by size of overlap region plus 0.0 weighted by size of non overlap region (implies xtr_frc)
+    } nco_xtr_typ_enm;
+
   /* CF Coordinates structure (20160503: Used only in ncks.c for to infer grids from CF coordinates convention) */
   typedef struct{ /* clm_bnd_sct */
     char *crd_nm[2]; /* [sng] Coordinate names */
@@ -1143,6 +1159,8 @@ extern "C" {
     char *fl_out; /* [sng] File containing regridded fields */
     char *fl_out_tmp; /* [sng] Temporary file containing regridded fields */
     char *fl_map; /* [sng] File containing mapping weights from source to destination grid */
+    char *fl_vrt; /* [sng] File containing vertical coordinate grid */
+    char *fl_msh;  /* [sng] File that contains SCRIP formatted overlap mesh */
     char *var_nm; /* [sng] Variable for special regridding treatment */
     // Grid names specifiable with key-value syntax
     char **rgr_arg; /* [sng] Regridding arguments */
@@ -1154,18 +1172,24 @@ extern "C" {
     char *fl_hnt_dst; /* [sng] ERWG hint destination */
     char *fl_hnt_src; /* [sng] ERWG hint source */
     char *frc_nm; /* [sng] Name of variable containing gridcell fraction */
+    char *ilev_nm_in; /* [sng] Name of input dimension to recognize as vertical dimension at layer interfaces */
+    char *ilev_nm_out; /* [sng] Name of output vertical dimension at layer interfaces */
     char *lat_bnd_nm; /* [sng] Name of rectangular boundary variable for latitude */
     char *lat_dmn_nm; /* [sng] Name of latitude dimension in inferred grid */
     char *lat_nm_in; /* [sng] Name of input dimension to recognize as latitude */
     char *lat_nm_out; /* [sng] Name of output dimension for latitude */
     char *lat_vrt_nm; /* [sng] Name of non-rectangular boundary variable for latitude */
     char *lat_wgt_nm; /* [sng] Name of variable containing latitude weights */
+    char *lev_nm_in; /* [sng] Name of input dimension to recognize as vertical dimension at layer midpoints */
+    char *lev_nm_out; /* [sng] Name of output vertical dimension at layer midpoints */
     char *lon_bnd_nm; /* [sng] Name of rectangular boundary variable for longitude */
     char *lon_dmn_nm; /* [sng] Name of longitude dimension in inferred grid */
     char *lon_nm_in; /* [sng] Name of dimension to recognize as longitude */
     char *lon_nm_out; /* [sng] Name of output dimension for longitude */
     char *lon_vrt_nm; /* [sng] Name of non-rectangular boundary variable for longitude */
     char *msk_nm; /* [sng] Name of variable containing destination mask */
+    char *sgs_frc_nm; /* [sng] Name of variable containing sub-gridscale fraction */
+    char *sgs_msk_nm; /* [sng] Name of variable containing sub-gridscale mask */
     char *vrt_nm; /* [sng] Name of dimension to employ for vertices */
     // User-specified grid properties
     char *fl_grd; /* [sng] Name of SCRIP grid file to create */
@@ -1179,12 +1203,14 @@ extern "C" {
     double lon_wst; /* [dgr] Longitude of western edge of grid */
     double lat_nrt; /* [dgr] Latitude of northern edge of grid */
     double lon_est; /* [dgr] Longitude of eastern edge of grid */
+    double sgs_nrm; /* [frc] Sub-gridscale normalization */
     long lat_nbr; /* [nbr] Number of latitudes in destination grid */
     long lon_nbr; /* [nbr] Number of longitudes in destination grid */
     nco_grd_2D_typ_enm grd_typ; /* [enm] Destination grid-type enum */
     nco_grd_lat_drc_enm lat_drc; /* [enm] Latitude grid-direction enum */
     nco_grd_lat_typ_enm lat_typ; /* [enm] Latitude grid-type enum */
     nco_grd_lon_typ_enm lon_typ; /* [enm] Longitude grid-type enum */
+    nco_xtr_typ_enm xtr_mth; /* [enm] Extrapolation method */
     // Other internal data and metadata 
     char **xtn_var; /* [sng] Extensive variables */
     char *cmd_ln; /* [sng] Command-line */
@@ -1210,7 +1236,7 @@ extern "C" {
     nco_bool flg_nfr; /* [flg] Infer SCRIP-format grid file */
     nco_bool flg_rnr; /* [flg] Renormalize destination values by valid area */
     nco_bool flg_stg; /* [flg] Write staggered grid with FV output */
-    nco_bool flg_usr_rqs; /* [flg] User requested regridding */
+    nco_bool flg_usr_rqs; /* [flg] User-requested regridding */
   } rgr_sct; /* end Regrid structure */
 
   /* Key-value structure */
@@ -1580,6 +1606,42 @@ extern "C" {
     size_t sz; /* [nbr] Size (non-hyperslabbed) of dimension */
   } dmn_cmn_sct;
 
+  typedef enum {
+     poly_none=0,
+     poly_sph=1,
+     poly_crt=2,
+     poly_rll=3
+  } poly_typ_enm;
+
+  typedef enum {
+      poly_vrl_pin,
+      poly_vrl_qin,
+      poly_vrl_unk
+  } poly_vrl_flg_enm;
+
+  typedef struct{
+    poly_typ_enm pl_typ;
+    int crn_nbr;           /* number of vertices */
+    double *dp_x;          /* x  vertices */
+    double *dp_y;          /* y vertices */
+    double dp_x_minmax[2]; /* x/lon minmax */
+    double dp_y_minmax[2]; /* y/lat minmax */
+    double dp_x_ctr;       /* x/lon center */
+    double dp_y_ctr;       /* x/lat center */
+    double area;
+    double **shp;    /* array of points size [crn_nbr][NBR] */
+    double wgt;      /* fraction of dst  area cell in overlap polygon */
+    double *dp_xyz;  /* maybe useful for 3D stuff */
+
+    nco_bool bwrp;   /* if true then whole polygon is wrapped - at Greenwich or Dateline */
+    nco_bool bwrp_y;
+    int src_id;      /* used in map file as  "row" or "col" id of polygon   */
+    int dst_id;     /* used in map file - used only in overlap polygon */
+
+    int  stat;
+    int mem_flg; /* [flg]    */ 
+  } poly_sct;   
+  
 #ifdef __cplusplus
 } /* end extern "C" */
 #endif /* !__cplusplus */
