@@ -94,6 +94,45 @@ nco_create_mode_prs /* [fnc] Parse user-specified file format */
   return rcd; /* [rcd] Return code */
 } /* end nco_create_mode_prs() */
 
+int /* O [enm] Return code */
+nco_fl_dmm_mk /* Create dummy file */
+(const char * const fl_out) /* I [sng] Dummy file */
+{
+  /* Purpose: Create dummy file for use by ncremap/ncks */
+
+  const char fnc_nm[]="nco_fl_dmm_mk()"; /* [sng] Function name */
+
+  char *fl_out_tmp=NULL_CEWI;
+
+  int fl_out_fmt=NC_FORMAT_CLASSIC; /* [enm] Output file format */
+  int dmn_id; /* [id] Dimension ID */
+  int out_id; /* I [id] Output netCDF file ID */
+  int rcd=NC_NOERR;
+
+  nco_bool FORCE_APPEND=False; /* Option A */
+  nco_bool FORCE_OVERWRITE=True; /* Option O */
+  nco_bool RAM_CREATE=False; /* [flg] Create file in RAM */
+  nco_bool RAM_OPEN=False; /* [flg] Open (netCDF3-only) file(s) in RAM */
+  nco_bool WRT_TMP_FL=False; /* [flg] Write output to temporary file */
+
+  size_t bfr_sz_hnt=NC_SIZEHINT_DEFAULT; /* [B] Buffer size hint */
+
+  /* Open dummy file */
+  fl_out_tmp=nco_fl_out_open(fl_out,&FORCE_APPEND,FORCE_OVERWRITE,fl_out_fmt,&bfr_sz_hnt,RAM_CREATE,RAM_OPEN,WRT_TMP_FL,&out_id);
+
+  rcd=nco_def_dim(out_id,"dummy",1L,&dmn_id);
+  if(rcd != NC_NOERR){
+    (void)fprintf(stdout,"%s: ERROR %s unable to open dummy file\n",nco_prg_nm_get(),fnc_nm);
+    nco_exit(EXIT_FAILURE);
+  } /* !rcd */
+  
+  /* Close output file and move it from temporary to permanent location */
+  (void)nco_fl_out_cls(fl_out,fl_out_tmp,out_id);
+
+  return NCO_NOERR;
+
+} /* !nco_fl_dmm_mk() */
+
 void
 nco_fl_sz_est /* [fnc] Estimate RAM size == uncompressed file size */
 (char *smr_fl_sz_sng, /* I/O [sng] String describing estimated file size */
@@ -346,7 +385,8 @@ nco_fl_lst_mk /* [fnc] Create file list from command line positional arguments *
  int arg_crr, /* I [idx] Index of current argument */
  int * const fl_nbr, /* O [nbr] Number of files in input file list */
  char ** const fl_out, /* I/O [sng] Name of output file */
- nco_bool *FL_LST_IN_FROM_STDIN) /* O [flg] fl_lst_in comes from stdin */
+ nco_bool *FL_LST_IN_FROM_STDIN, /* O [flg] fl_lst_in comes from stdin */
+ const nco_bool FORCE_OVERWRITE) /* I [flg] Overwrite existing file, if any */
 {
   /* Purpose: Parse positional arguments on command line
      Name of calling program plays a role in this */
@@ -358,7 +398,7 @@ nco_fl_lst_mk /* [fnc] Create file list from command line positional arguments *
      Multi-file operators take input filenames from positional arguments, if any
      Otherwise, multi-file operators try to get input filenames from stdin */
 
-  //  const char fnc_nm[]="nco_fl_lst_mk()"; /* [sng] Function name */
+  const char fnc_nm[]="nco_fl_lst_mk()"; /* [sng] Function name */
 
   nco_bool FL_OUT_FROM_PSN_ARG=True; /* [flg] fl_out comes from positional argument */
 
@@ -381,20 +421,80 @@ nco_fl_lst_mk /* [fnc] Create file list from command line positional arguments *
     psn_arg_fst=1;
   } /* end if */
 
-  /* Might there be problems with any specified files? */
-  for(idx=arg_crr;idx<argc;idx++){
-    if((int)strlen(argv[idx]) >= fl_nm_sz_wrn) (void)fprintf(stderr,"%s: WARNING filename %s is very long (%ld characters) and may not be portable to older operating systems\n",nco_prg_nm_get(),argv[idx],(long int)strlen(argv[idx]));
-  } /* end loop over idx */
-
-  /* All operators except multi-file operators must have at least one positional argument */
-  if(!nco_is_mfo(nco_prg_id) && psn_arg_nbr == 0){
+  /* All operators except multi-file operators and possibly must have at least one positional argument */
+  if(!nco_is_mfo(nco_prg_id) && FL_OUT_FROM_PSN_ARG && psn_arg_nbr == 0){
     (void)fprintf(stdout,"%s: ERROR received %d filenames; need at least one\n",nco_prg_nm_get(),psn_arg_nbr);
     (void)nco_usg_prn();
     nco_exit(EXIT_FAILURE);
   } /* end if */
 
+  /* psn_arg_nbr can be 0 for ncap2 */
+  if(psn_arg_nbr > 0){
+    /* Might there be problems with any specified files? */
+    for(idx=arg_crr;idx<argc;idx++){
+      if((int)strlen(argv[idx]) >= fl_nm_sz_wrn) (void)fprintf(stderr,"%s: WARNING filename %s is very long (%ld characters) and may not play well with older operating systems\n",nco_prg_nm_get(),argv[idx],(long int)strlen(argv[idx]));
+    } /* end loop over idx */
+  } /* !psn_arg_nbr */
+  
+  /* ncap2 dummy file */
+  const char tmp_sng_1[]="_tmp_dmm.nc.pid"; /* Extra string appended to temporary filenames */
+  char *fl_dmm;
+  int rcd_stt=NC_MIN_INT; /* [rcd] Return code from stat() */
+  long fl_dmm_lng; /* [nbr] Length of dummy file name */
+  pid_t pid; /* Process ID */
+  struct stat stat_sct;
+
   switch(nco_prg_id){
+    /* 20190414 Given ncap2 its own block so it can have no input files 
+       Previously, ncap2 used ncatted/ncks/ncrename code block below, but this often required supplying dummy filenames */
   case ncap:
+    /* Operators with optional fl_in and required fl_out */
+    if(psn_arg_nbr > 2-psn_arg_fst){
+      if(FL_OUT_FROM_PSN_ARG) (void)fprintf(stdout,"%s: ERROR received %d filenames; need no more than two\n",nco_prg_nm_get(),psn_arg_nbr); else (void)fprintf(stdout,"%s: ERROR received %d input filenames; need no more than one (output file was specified with -o switch)\n",nco_prg_nm_get(),psn_arg_nbr);
+      (void)nco_usg_prn();
+      nco_exit(EXIT_FAILURE);
+    } /* end if */
+
+    /* ncap2 always has one input file, whether dummy or real */
+    fl_lst_in=(char **)nco_malloc(sizeof(char *)); /* fxm: free() this memory sometime */
+
+    if((!FL_OUT_FROM_PSN_ARG && psn_arg_nbr == 0) || (FL_OUT_FROM_PSN_ARG && psn_arg_nbr == 1)){
+      /* ncap2 was called with a single filename argument
+	 If that file exists, treat it as both input and output file
+	 Otherwise, treat it as output file and create dummy input file */
+      rcd_stt=stat(argv[arg_crr],&stat_sct);
+      if(rcd_stt == 0 && !FORCE_OVERWRITE){
+	/* Single file exists, use it as input file */
+	fl_lst_in[(*fl_nbr)++]=(char *)strdup(argv[arg_crr++]);
+      }else if((rcd_stt == -1) || (rcd_stt == 0 && FORCE_OVERWRITE)){
+	if((nco_dbg_lvl_get() >= nco_dbg_fl) && (rcd_stt == -1)) (void)fprintf(stderr,"\n%s: DEBUG stat() #1 failed: %s does not exist. Will assume %s will be brand-new output file and will create dummy input file...\n",nco_prg_nm_get(),argv[arg_crr],argv[arg_crr]);
+	if((nco_dbg_lvl_get() >= nco_dbg_fl) && (rcd_stt == 0)) (void)fprintf(stderr,"\n%s: DEBUG stat() #1 succeeded: %s exists but FORCE_OVERWRITE is true so will overwrite existing %s and will create dummy input file...\n",nco_prg_nm_get(),argv[arg_crr],argv[arg_crr]);
+	pid=getpid();
+	/* ncap2 dummy file name is "ncap2" + tmp_sng_1 + PID + NUL */
+	fl_dmm_lng=strlen(nco_prg_nm_get())+strlen(tmp_sng_1)+8UL+1UL;
+	/* NB: Calling routine has responsibility to free() this memory */
+	fl_dmm=(char *)nco_malloc(fl_dmm_lng*sizeof(char));
+	(void)sprintf(fl_dmm,"%s%s%ld",nco_prg_nm_get(),tmp_sng_1,(long)pid);
+	(void)nco_fl_dmm_mk(fl_dmm);
+	fl_lst_in[(*fl_nbr)++]=fl_dmm;
+      } /* !rcd_stt */
+    }else if(psn_arg_nbr == 2){
+      fl_lst_in[(*fl_nbr)++]=(char *)strdup(argv[arg_crr++]);
+    } /* !psn_arg_nbr */
+
+      /* Output file is mandatory for ncap2
+       If positional (not specified with -o), create here unless single file is both input and output (like ncatted/ncrename)
+       Last clause prevents prevents using results of stat() check
+       When rcd_stt == 0, calling routine (ncap2 main()) does special file open procedure */
+    if((arg_crr == argc-1) && FL_OUT_FROM_PSN_ARG && (rcd_stt != 0 || FORCE_OVERWRITE)){
+      *fl_out=(char *)strdup(argv[arg_crr]);
+      //*fl_out=nco_sng_sntz(*fl_out);
+    } /* !arg_crr */
+
+    if(nco_dbg_lvl_get() >= nco_dbg_scl) (void)fprintf(stdout,"%s: DEBUG %s reports psn_arg_nbr = %d, psn_arg_fst = %d, arg_crr = %d,argc = %d, fl_lst_in[0]=%s, *fl_nbr=%d, *fl_out = %s\n",nco_prg_nm_get(),fnc_nm,psn_arg_nbr,psn_arg_fst,arg_crr,argc,fl_lst_in[0],*fl_nbr,*fl_out);
+
+    return fl_lst_in;
+    /* break; *//* NB: break after return in case statement causes SGI cc warning */
   case ncatted:
   case ncks:
   case ncrename:
