@@ -152,6 +152,63 @@ nco_cpy_prn(void) /* [fnc] Print copyright notice */
   (void)fprintf(stdout,"This program is part of NCO, the netCDF Operators.\nNCO is free software and comes with a BIG FAT KISS and ABSOLUTELY NO WARRANTY\nYou may redistribute and/or modify NCO under the terms of the\nGNU General Public License (GPL) Version 3 with exceptions described in the LICENSE file\nGPL: http://www.gnu.org/copyleft/gpl.html\nLICENSE: https://github.com/nco/nco/tree/master/LICENSE\n");
 } /* end copyright_prn() */
 
+void
+nco_lbr_vrs_prn(void) /* [fnc] Print netCDF library version */
+{
+  /* Purpose: Print netCDF library version */
+
+  char *cmp_dat_sng;
+  char *dlr_ptr;
+  char *lbr_sng;
+  char *lbr_vrs_sng;
+  char *of_ptr;
+
+  size_t cmp_dat_sng_lng;
+  size_t lbr_vrs_sng_lng;
+
+  /* Behavior of nc_inq_libvers() depends on library versions. Return values are:
+     netCDF 3.4--3.6.x: "3.4 of May 16 1998 14:06:16 $"
+     netCDF 4.0-alpha1--4.0-alpha10: NULL
+     netCDF 4.0-alpha11--4.0-alpha16: "4.0-alpha11"
+     netCDF 4.0-beta1--4.4: "4.0-beta1"
+     netCDF 4.4--present: "4.5.0-development" */  
+  lbr_sng=(char *)strdup(nc_inq_libvers());
+  /* (void)fprintf(stderr,"%s: nco_lbr_vrs_prn() returns %s\n",nco_prg_nm_get(),lbr_sng);*/
+  of_ptr=strstr(lbr_sng," of ");
+  if(of_ptr == NULL){
+    (void)fprintf(stderr,"%s: WARNING nco_lbr_vrs_prn() reports of_ptr == NULL\n",nco_prg_nm_get());
+    lbr_vrs_sng_lng=(size_t)strlen(lbr_sng);
+  }else{
+    lbr_vrs_sng_lng=(size_t)(of_ptr-lbr_sng);
+  } /* endif */
+  lbr_vrs_sng=(char *)nco_malloc(lbr_vrs_sng_lng+1ul);
+  strncpy(lbr_vrs_sng,lbr_sng,lbr_vrs_sng_lng);
+  lbr_vrs_sng[lbr_vrs_sng_lng]='\0'; /* NUL-terminate */
+
+  dlr_ptr=strstr(lbr_sng," $");
+  if(of_ptr && dlr_ptr){
+    cmp_dat_sng_lng=(size_t)(dlr_ptr-of_ptr-4ul); /* 4 is the length of " of " */
+    cmp_dat_sng=(char *)nco_malloc(cmp_dat_sng_lng+1ul);
+    strncpy(cmp_dat_sng,of_ptr+4ul,cmp_dat_sng_lng); /* 4 is the length of " of " */
+    cmp_dat_sng[cmp_dat_sng_lng]='\0'; /* NUL-terminate */
+  }else{
+    cmp_dat_sng=(char *)strdup("Unknown");
+  } /* endif */
+
+  (void)fprintf(stderr,"Linked to netCDF library version %s compiled %s\n",lbr_vrs_sng,cmp_dat_sng);
+
+  cmp_dat_sng=(char *)nco_free(cmp_dat_sng);
+  lbr_vrs_sng=(char *)nco_free(lbr_vrs_sng);
+  lbr_sng=(char *)nco_free(lbr_sng);
+} /* end nco_lbr_vrs_prn() */
+
+const char * /* O [sng] Mnemonic that describes current NCO version */
+nco_nmn_get(void) /* [fnc] Return mnemonic that describes current NCO version */
+{ 
+  /* Purpose: Return mnemonic describing current NCO version */
+  return "INDICES";
+} /* end nco_nmn_get() */
+
 void
 nco_vrs_prn /* [fnc] Print NCO version */
 (const char * const CVS_Id, /* I [sng] CVS identification string */
@@ -210,7 +267,7 @@ nco_vrs_prn /* [fnc] Print NCO version */
   }else{
     /* 20141008: Try new nco.h-based versioning */
     /*    (void)fprintf(stderr,"NCO netCDF Operators version %s built %s on %s by %s\n",vrs_sng,date_cpp,hst_cpp,usr_cpp);*/
-    (void)fprintf(stderr,"NCO netCDF Operators version %s built by %s on %s at %s %s\n",vrs_sng,usr_cpp,hst_cpp,date_cpp,time_cpp);
+    (void)fprintf(stderr,"NCO netCDF Operators version %s \"%s\" built by %s on %s at %s %s\n",vrs_sng,nco_nmn_get(),usr_cpp,hst_cpp,date_cpp,time_cpp);
   } /* endif */
   if(strlen(CVS_Id) > strlen("*Id*")){
     vrs_cvs=cvs_vrs_prs();
