@@ -344,8 +344,10 @@ main(int argc,char **argv)
     {"msk_cnd_sng",required_argument,0,'B'},
     {"retain-degenerate-dimensions",no_argument,0,'b'}, /* [flg] Retain degenerate dimensions */
     {"rdd",no_argument,0,'b'}, /* [flg] Retain degenerate dimensions */
-    {"no-coords",no_argument,0,'C'},
-    {"no-crd",no_argument,0,'C'},
+    {"xtr_ass_var",no_argument,0,'c'},
+    {"xcl_ass_var",no_argument,0,'C'},
+    {"no_coords",no_argument,0,'C'},
+    {"no_crd",no_argument,0,'C'},
     {"coords",no_argument,0,'c'},
     {"crd",no_argument,0,'c'},
     {"debug",required_argument,0,'D'},
@@ -716,7 +718,7 @@ main(int argc,char **argv)
   if(!wgt_nm) NORMALIZE_BY_WEIGHT=False;
 
   /* Process positional arguments and fill-in filenames */
-  fl_lst_in=nco_fl_lst_mk(argv,argc,optind,&fl_nbr,&fl_out,&FL_LST_IN_FROM_STDIN);
+  fl_lst_in=nco_fl_lst_mk(argv,argc,optind,&fl_nbr,&fl_out,&FL_LST_IN_FROM_STDIN,FORCE_OVERWRITE);
 
   /* Initialize thread information */
   thr_nbr=nco_openmp_ini(thr_nbr);
